@@ -50,7 +50,6 @@ def type_to_amogus(type_: SusType, obj_types: Dict[str, str]) -> str:
     if type_.name == "List":
         elements = type_to_amogus(type_.args[0], obj_types)
         return f"new amogus.repr.List({elements}, {type_.args[1]}, {type_validators(type_)})"
-
     if type_.name == "Entity":
         return "new amogus.repr.Entity()"
 
@@ -60,22 +59,30 @@ def type_to_amogus(type_: SusType, obj_types: Dict[str, str]) -> str:
             "entities": "Entity",
             "bitfields": "EnumOrBf",
             "enums": "EnumOrBf",
-            "confirmations": "Confirmation"
+            "confirmations": "Confirmation",
+            "compounds": "Compound"
         }[obj_types[type_.name]]
 
-        if t_name == "EnumOrBf":
-            return f"new amogus.repr.EnumOrBf<{type_.name}>({type_.name}_SIZE)"
-
         if t_name == "Entity":
             return "new amogus.repr.Entity()"
+
+        if t_name == "Compound":
+            return f"new amogus.repr.FieldArray({type_.name}Spec)"
+
+        if t_name == "EnumOrBf":
+            return f"new amogus.repr.EnumOrBf<{type_.name}>({type_.name}_SIZE)"
         
         return f"new amogus.repr.{t_name}({type_.name})"
 
-    return f"new amogus.repr.{type_.name}({', '.join([str(x) for x in type_.args] + [''])}{type_validators(type_)})"
+    name = type_.name
+    if name == "Int" and type_.args[0] > 6:
+        name = "BigInteger"
+
+    return f"new amogus.repr.{name}({', '.join([str(x) for x in type_.args] + [''])}{type_validators(type_)})"
 
 def write_output(root_file: SusFile, target_dir: str) -> None:
     proj_name = path.splitext(path.basename(root_file.path))[0]
-    header = ("/* Generated by AMOGUS SUS (https://github.com/portasynthinca3/amogus)\n"
+    header = ("/* Generated by AMOGUS SUSC (https://github.com/amogus-api/susc)\n"
     f" * Project name: {proj_name}\n *\n"
     "" + LICENSE + "\n */\n\n")
 
@@ -94,6 +101,14 @@ def write_output(root_file: SusFile, target_dir: str) -> None:
         f.write(header)
         f.write("import * as amogus from \"amogus-driver\";\n\n")
 
+        # write compounds
+        compounds = [t for t in root_file.things if isinstance(t, SusCompound)]
+        for thing in compounds:
+            write_docstr(f, thing)
+            f.write(f"export const {thing.name}Spec = {'{'}\n")
+            write_field_array(f, thing.fields, objs, 1)
+            f.write("};\n\n")
+
         # write enums
         enums_and_bfs = [t for t in root_file.things if isinstance(t, (SusEnum, SusBitfield))]
         for thing in enums_and_bfs:
@@ -106,7 +121,7 @@ def write_output(root_file: SusFile, target_dir: str) -> None:
             f.write("}\n")
             f.write(f"export const {thing.name}_SIZE = {thing.size};\n\n\n")
 
-        # write confirmation
+        # write confirmations
         confirmations = [t for t in root_file.things if isinstance(t, SusConfirmation)]
         for conf in confirmations:
             # write spec
@@ -240,7 +255,7 @@ def write_output(root_file: SusFile, target_dir: str) -> None:
                 f.write("\t}\n")
 
             # write $get()
-            f.write("\n\tstatic async $get(id: number) {\n")
+            f.write("\n\tstatic async $get(id: bigint) {\n")
             f.write(f"\t\treturn (await this.get({'{'} id {'}'})).entity as amogus.ValuedEntity<{entity.name}>;\n")
             f.write("\t}\n")
 
