@@ -70,6 +70,14 @@ class SusType(SusTypeBase):
                 return "Bool takes no arguments"
             if len(self.validators) != 0:
                 return "Bool can't be validated"
+        elif self.name == "Bin":
+            if len(self.args) != 0:
+                return "Bin takes no arguments"
+            for v in self.validators:
+                if v.param != "len":
+                    return "The following validators are valid for Bin: 'len'"
+                if not isinstance(v.restriction, range):
+                    return "Bin[len] must be a range"
         elif self.name not in identifiers:
             return "Unknown type"
 
@@ -165,6 +173,7 @@ def convert_docstring(doc: str) -> str:
 def convert_ebf_members(ast, file): # Enum or Bitfield
     list = []
     for member in ast:
+        if not member: continue
         doc = convert_docstring(member.children[0])
         name = member.children[1]
         value = int(member.children[2].value)
@@ -178,9 +187,6 @@ def convert_range(ast, max_val):
         return range(int(ast.children[0].value), int(ast.children[1].value) + 1) # python ranges exclude the right end
 
 def convert_type(ast, file):
-    if ast.data == "compound":
-        return convert_compound_type(ast, file)
-
     name = ast.children[0]
     args = []
     validators = []
@@ -224,15 +230,6 @@ def convert_type(ast, file):
     location = SusLocation(file, name.line, name.column, len(name.value))
     return SusType(location, None, name.value, args, validators)
 
-def convert_compound_type(ast, file):
-    members = []
-    for i in range(0, len(ast.children), 2):
-        name = ast.children[i]
-        type_ = ast.children[i + 1]
-        members.append(SusCompoundMember(SusLocation(file, name.line, name.column, len(name.value)),
-            name.value, convert_type(type_, file)))
-    return SusCompound(SusLocation(file, 0, 0, len("compound")), None, members)
-
 def convert_opt(ast):
     if ast is None:
         return ast
@@ -291,6 +288,7 @@ def convert_method(ast, file):
 
     params, returns, errors, confirmations, states, rate_limit = [], [], [], [], [], None
     for directive in ast.children[3:]:
+        if not directive: continue
         if directive.data == "method_param":
             params.append(convert_param(directive, file))
         elif directive.data == "returns":
@@ -353,8 +351,8 @@ def convert_ast(ast, file):
         req = ast.children[3]
         resp = ast.children[4]
 
-        req = [convert_param(par, file) for par in req.children]
-        resp = [convert_param(par, file) for par in resp.children]
+        req = [convert_param(par, file) for par in req.children if par]
+        resp = [convert_param(par, file) for par in resp.children if par]
 
         return SusConfirmation(SusLocation(file, name.line, name.column, len(name)), doc, name.value, value,
             req, resp)
@@ -366,6 +364,7 @@ def convert_ast(ast, file):
         directives = ast.children[2:]
         fields, methods = [], []
         for directive in directives:
+            if not directive: continue
             doc = convert_docstring(directive.children[0])
             identifier = directive.children[1]
             opt = convert_opt(directive.children[2])
